import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.userentity import USERENTITIES_ENDPOINT, UserEntity
from pygrocydm.grocy_api_client import GrocyApiClient


class TestUserEntity(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = USERENTITIES_ENDPOINT + '/1'

    def test_userentity_data_diff_valid(self):
        userentity = self.api.get_request(self.endpoint)
        userentity_keys = userentity.keys()
        moked_userentity_json = """{
            "id": "1",
            "name": "exampleuserentity",
            "caption": "Example userentity",
            "description": "This is an example user entity...",
            "show_in_sidebar_menu": "1",
            "icon_css_class": "fas fa-smile",
            "row_created_timestamp": "2020-03-06 00:50:10"
        }"""
        moked_keys = json.loads(moked_userentity_json).keys()
        self.assertCountEqual(list(userentity_keys), list(moked_keys))

    def test_parse_json(self):
        userentity = UserEntity(self.api, USERENTITIES_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(userentity.id, int)
        assert isinstance(userentity.name, str)
        assert isinstance(userentity.caption, str)
        assert isinstance(userentity.description, str) or userentity.description is None
        assert isinstance(userentity.show_in_sidebar_menu, bool)
        assert isinstance(userentity.icon_css_class, str) or userentity.icon_css_class is None
        assert isinstance(userentity.row_created_timestamp, datetime)



from datetime import datetime

from .grocy_api_client import GrocyApiClient, GrocyEntity
from .utils import parse_bool, parse_date, parse_int

TASKS_ENDPOINT = 'objects/tasks'


class Task(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__name = parsed_json.get('name')
        self.__description = parsed_json.get('description', None)
        self.__due_date = parse_date(parsed_json.get('due_date', None))
        self.__done = parse_bool(parsed_json.get('done'), False)
        self.__done_timestamp = parse_date(
            parsed_json.get('done_timestamp', None))
        self.__category_id = parse_int(parsed_json.get('category_id'), None)
        self.__assigned_to_user_id = parse_int(
            parsed_json.get('assigned_to_user_id'))
        super().__init__(api, endpoint, parsed_json)

    @property
    def name(self) -> str:
        return self.__name

    @property
    def description(self) -> str:
        return self.__description

    @property
    def due_date(self) -> datetime:
        return self.__due_date

    @property
    def done(self) -> bool:
        return self.__done

    @property
    def done_timestamp(self) -> datetime:
        return self.__done_timestamp

    @property
    def category_id(self) -> int:
        return self.__category_id

    @property
    def assigned_to_user_id(self) -> int:
        return self.__assigned_to_user_id



from .grocy_api_client import GrocyApiClient, GrocyEntity

QUANTITY_UNITS_ENDPOINT = 'objects/quantity_units'


class QuantityUnit(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__name = parsed_json.get('name')
        self.__name_plural = parsed_json.get('name_plural')
        self.__description = parsed_json.get('description', None)
        self.__plural_forms = parsed_json.get('plural_forms', None)
        super().__init__(api, endpoint, parsed_json)

    @property
    def name(self) -> str:
        return self.__name

    @property
    def name_plural(self) -> str:
        return self.__name_plural

    @property
    def plural_forms(self) -> str:
        return self.__plural_forms

    @property
    def description(self) -> str:
        return self.__description



from .grocy_api_client import GrocyApiClient, GrocyEntity
from .utils import parse_bool

USERENTITIES_ENDPOINT = 'objects/userentities'


class UserEntity(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__name = parsed_json.get('name')
        self.__caption = parsed_json.get('caption')
        self.__description = parsed_json.get('description', None)
        self.__show_in_sidebar_menu = parse_bool(
            parsed_json.get('show_in_sidebar_menu'), False)
        self.__icon_css_class = parsed_json.get('icon_css_class', None)
        super().__init__(api, endpoint, parsed_json)

    @property
    def name(self) -> str:
        return self.__name

    @property
    def caption(self) -> str:
        return self.__caption

    @property
    def description(self) -> str:
        return self.__description

    @property
    def show_in_sidebar_menu(self) -> bool:
        return self.__show_in_sidebar_menu

    @property
    def icon_css_class(self) -> str:
        return self.__icon_css_class



from enum import Enum

from .grocy_api_client import GrocyApiClient, GrocyEntity
from .utils import parse_bool

USERFIELDS_ENDPOINT = 'objects/userfields'


class UserfieldType(Enum):
    TEXT_SINGLE_LINE = "text-single-line"
    TEXT_MULTI_LINE = "text-multi-line"
    NUMBER_INTEGRAL = "number-integral"
    NUMBER_DECIMAL = "number-decimal"
    DATE = "date"
    DATETIME = "datetime"
    CHECKBOX = "checkbox"
    LINK = "link"
    PRESET_LIST = "preset-list"
    PRESET_CHECKLIST = "preset-checklist"


class Userfield(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__entity = parsed_json.get('entity')
        self.__name = parsed_json.get('name')
        self.__caption = parsed_json.get('caption')
        self.__type = parsed_json.get('type')
        self.__show_as_column_in_tables = parse_bool(
            parsed_json.get('show_as_column_in_tables'), False)
        self.__config = parsed_json.get('config', None)
        super().__init__(api, endpoint, parsed_json)

    @property
    def entity(self) -> str:
        return self.__entity

    @property
    def name(self) -> str:
        return self.__name

    @property
    def caption(self) -> str:
        return self.__caption

    @property
    def type(self) -> str:
        return self.__type

    @property
    def show_as_column_in_tables(self) -> bool:
        return self.__show_as_column_in_tables

    @property
    def config(self) -> str:
        return self.__config



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.task import TASKS_ENDPOINT, Task
from pygrocydm.grocy_api_client import GrocyApiClient


class TestTask(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = TASKS_ENDPOINT + '/1'

    def test_task_data_diff_valid(self):
        task = self.api.get_request(self.endpoint)
        task_keys = task.keys()
        moked_task_json = """{
            "id": "1",
            "name": "Repair the garage door",
            "description": null,
            "due_date": "2020-03-18",
            "done": "0",
            "done_timestamp": null,
            "category_id": "1",
            "assigned_to_user_id": "1",
            "row_created_timestamp": "2020-03-04 00:50:14"
        }"""
        moked_keys = json.loads(moked_task_json).keys()
        self.assertCountEqual(list(task_keys), list(moked_keys))

    def test_parse_json(self):
        task = Task(self.api, TASKS_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(task.id, int)
        assert isinstance(task.description, str) or not task.description
        assert isinstance(task.name, str)
        assert isinstance(task.due_date, (datetime, None)) or not task.description
        assert isinstance(task.done, bool)
        assert isinstance(task.done_timestamp, datetime) or not task.description
        assert isinstance(task.category_id, int) or not task.description
        assert isinstance(task.assigned_to_user_id, int)
        assert isinstance(task.row_created_timestamp, datetime)



import json
from datetime import datetime
from typing import Tuple
from urllib.parse import urljoin

import requests

from .utils import parse_date, parse_int

DEFAULT_PORT_NUMBER = 9192


class GrocyApiClient():
    def __init__(
                self, base_url, api_key,
                port: int = DEFAULT_PORT_NUMBER, verify_ssl=True):
        self.__base_url = f"{base_url}:{port}/api/"
        self.__api_key = api_key
        self.__verify_ssl = verify_ssl
        if self.__api_key == "demo_mode":
            self.__headers = {"accept": "application/json"}
        else:
            self.__headers = {
                "accept": "application/json",
                "GROCY-API-KEY": api_key
            }

    def get_request(self, endpoint: str):
        req_url = urljoin(self.__base_url, endpoint)
        resp = requests.get(
            req_url, verify=self.__verify_ssl, headers=self.__headers)
        resp.raise_for_status()
        if len(resp.content) > 0:
            return resp.json()

    def post_request(self, endpoint: str, data: dict):
        req_url = urljoin(self.__base_url, endpoint)
        resp = requests.post(
            req_url, verify=self.__verify_ssl,
            headers=self.__headers,
            data=data)
        resp.raise_for_status()
        if len(resp.content) > 0:
            return resp.json()

    def delete_request(self, endpoint: str):
        req_url = urljoin(self.__base_url, endpoint)
        resp = requests.delete(
            req_url, verify=self.__verify_ssl,
            headers=self.__headers)
        resp.raise_for_status()

    def put_request(self, endpoint: str, data: dict):
        up_header = self.__headers.copy()
        up_header['accept'] = '*/*'
        up_header['Content-Type'] = 'application/json'
        req_url = urljoin(self.__base_url, endpoint)
        resp = requests.put(
            req_url, verify=self.__verify_ssl,
            headers=up_header,
            data=json.dumps(data))
        resp.raise_for_status()


class GrocyEntity():
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json: json):
        self.__api = api
        self.__parsed_json = parsed_json
        self.__id = parse_int(parsed_json.get('id'))
        self.__endpoint = f"{endpoint}/{self.__id}"
        self.__row_created_timestamp = parse_date(
            parsed_json.get('row_created_timestamp'))

    def edit(self, data: dict):
        return self.__api.put_request(self.__endpoint, data)

    def delete(self):
        return self.__api.delete_request(self.__endpoint)

    @property
    def id(self) -> int:
        return self.__id

    @property
    def row_created_timestamp(self) -> datetime:
        return self.__row_created_timestamp


class GrocyEntityList():
    def __init__(self, api: GrocyApiClient, cls, endpoint: str):
        self.__api = api
        self.__cls = cls
        self.__endpoint = endpoint
        self.__list = None
        self.refresh()

    def refresh(self):
        parsed_json = self.__api.get_request(self.__endpoint)
        if parsed_json:
            self.__list = tuple(
                [self.__cls(
                    self.__api, self.__endpoint,
                    response) for response in parsed_json])

    def add(self, item: dict):
        resp = self.__api.post_request(self.__endpoint, item)
        if resp:
            self.refresh()
            return parse_int(resp.get('created_object_id'))

    def search(self, search_str: str) -> Tuple[GrocyEntity]:
        endpoint = f"{self.__endpoint}/search/{search_str}"
        parsed_json = self.__api.get_request(endpoint)
        if parsed_json:
            return tuple(
                [self.__cls(
                    self.__api, self.__endpoint,
                    response) for response in parsed_json])
        return None

    @property
    def list(self) -> Tuple[GrocyEntity]:
        return self.__list



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.grocy_api_client import GrocyApiClient
from pygrocydm.equipment import EQUIPMENT_ENDPOINT, Equipment


class TestEquipment(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = EQUIPMENT_ENDPOINT + '/1'

    def test_equipment_data_diff_valid(self):
        equipment = self.api.get_request(self.endpoint)
        equipment_keys = equipment.keys()
        moked_equipment_json = """{
            "id": "1",
            "name": "Coffee machine",
            "description": null,
            "row_created_timestamp": "2020-03-05 00:50:10",
            "instruction_manual_file_name": "loremipsum.pdf"
        }"""
        moked_keys = json.loads(moked_equipment_json).keys()
        self.assertCountEqual(list(equipment_keys), list(moked_keys))

    def test_parse_json(self):
        equipment = Equipment(self.api, EQUIPMENT_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(equipment.id, int)
        assert isinstance(equipment.description, str) or equipment.description is None
        assert isinstance(equipment.name, str)
        assert isinstance(equipment.instruction_manual_file_name, str) or not equipment.instruction_manual_file_name
        assert isinstance(equipment.row_created_timestamp, datetime)



from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

import responses
from requests.exceptions import HTTPError

from pygrocydm import GrocyDataManager
from pygrocydm.battery import Battery
from pygrocydm.chore import Chore
from pygrocydm.equipment import Equipment
from pygrocydm.location import Location
from pygrocydm.product import Product
from pygrocydm.product_group import ProductGroup
from pygrocydm.quantity_unit import QuantityUnit
from pygrocydm.quantity_unit_conversion import QuantityUnitConversion
from pygrocydm.shopping_list import ShoppingList, ShoppingListItem
from pygrocydm.task import Task
from pygrocydm.task_category import TaskCategory
from pygrocydm.userentity import UserEntity
from pygrocydm.userfield import Userfield
from pygrocydm.userobject import UserObject


class TestGrocyDataManager(TestCase):

    def setUp(self):
        self.gdm = GrocyDataManager(CONST_BASE_URL, "api_key")
        self.gdm = None
        self.gdm = GrocyDataManager(CONST_BASE_URL, "demo_mode",  verify_ssl = CONST_SSL, port = CONST_PORT)

    def test_init(self):
        assert isinstance(self.gdm, GrocyDataManager)

    def test_products_valid(self):
        products = self.gdm.products().list
        assert isinstance(products, tuple)
        assert len(products) >=1
        for product in products:
            assert isinstance(product, Product)

    @responses.activate
    def test_products_invalid_no_data(self):
        resp = []
        responses.add(responses.GET,
            '{}:{}/api/objects/products'.format(CONST_BASE_URL, CONST_PORT),
            json=resp,
            status=200)
        products = self.gdm.products().list
        assert products is None

    @responses.activate
    def test_products_error(self):
        responses.add(responses.GET,
            '{}:{}/api/objects/products'.format(CONST_BASE_URL, CONST_PORT),
            status=400)
        self.assertRaises(HTTPError, self.gdm.products)

    def test_chores_valid(self):
        chores = self.gdm.chores().list
        assert isinstance(chores, tuple)
        assert len(chores) >=1
        for chore in chores:
            assert isinstance(chore, Chore)

    def test_locations_valid(self):
        locations = self.gdm.locations().list
        assert isinstance(locations, tuple)
        assert len(locations) >=1
        for location in locations:
            assert isinstance(location, Location)

    def test_batteries_valid(self):
        batteries = self.gdm.batteries().list
        assert isinstance(batteries, tuple)
        assert len(batteries) >=1
        for battery in batteries:
            assert isinstance(battery, Battery)

    def test_shopping_list_items_valid(self):
        shopping_list_items = self.gdm.shopping_list().list
        assert isinstance(shopping_list_items, tuple)
        assert len(shopping_list_items) >=1
        for items in shopping_list_items:
            assert isinstance(items, ShoppingListItem)

    def test_shopping_lists_valid(self):
        shopping_lists = self.gdm.shopping_lists().list
        assert isinstance(shopping_lists, tuple)
        assert len(shopping_lists) >=1
        for shopping_list in shopping_lists:
            assert isinstance(shopping_list, ShoppingList)

    def test_add_product_valid(self):
        product_list = self.gdm.products()
        old_len = len(product_list.list)
        new_product = {}
        new_product['name'] = 'Test product'
        new_product['location_id'] = 1
        new_product['qu_id_purchase'] = 1
        new_product['qu_id_stock'] = 1
        new_product['qu_factor_purchase_to_stock'] = 1
        new_product_id = product_list.add(new_product)
        new_len = len(product_list.list)
        assert isinstance(new_product_id, int)
        assert new_len == old_len + 1

    def test_add_product_error(self):
        product_list = self.gdm.products()
        new_product = {}
        new_product['name'] = 'Test product'
        self.assertRaises(HTTPError, product_list.add, new_product)

    def test_edit_product_valid(self):
        fields = {}
        fields['name'] = 'Test'
        assert not self.gdm.products().list[-1].edit(fields)

    def test_edit_product_error(self):
        fields = {}
        fields['nam'] = 'Test'
        product = self.gdm.products().list[0]
        self.assertRaises(HTTPError, product.edit, fields)

    def test_product_delete_valid(self):
        product = self.gdm.products().list[-1]
        old_len = len(self.gdm.products().list)
        assert not product.delete()
        self.gdm.products().refresh()
        new_len = len(self.gdm.products().list)
        assert new_len == old_len - 1

    def test_product_delete_error(self):
        product = self.gdm.products().list[-1]
        product.delete()
        self.assertRaises(HTTPError, product.delete)

    def test_search_product_valid(self):
        products = self.gdm.products().search("Co")
        assert isinstance(products, tuple)
        assert len(products) >=1
        for product in products:
            assert isinstance(product, Product)

    def test_search_product_invalid_no_data(self):
        products = self.gdm.products().search("Toto")
        assert products is None

    @responses.activate
    def test_search_product_error(self):
        url = '{}:{}/api/objects/products'.format(CONST_BASE_URL, CONST_PORT)
        responses.add_passthru(url)
        responses.add(responses.GET,
            '{}/search/error'.format(url),
            status=400)
        products = self.gdm.products()
        self.assertRaises(HTTPError, products.search, "error")

    def test_quantity_units_valid(self):
        quantity_units = self.gdm.quantity_units().list
        assert isinstance(quantity_units, tuple)
        assert len(quantity_units) >=1
        for quantity_unit in quantity_units:
            assert isinstance(quantity_unit, QuantityUnit)

    def test_tasks_valid(self):
        tasks = self.gdm.tasks().list
        assert isinstance(tasks, tuple)
        assert len(tasks) >=1
        for task in tasks:
            assert isinstance(task, Task)

    def test_task_categories_valid(self):
        task_categories = self.gdm.task_categories().list
        assert isinstance(task_categories, tuple)
        assert len(task_categories) >=1
        for task_category in task_categories:
            assert isinstance(task_category, TaskCategory)

    def test_product_groups_valid(self):
        product_groups = self.gdm.product_groups().list
        assert isinstance(product_groups, tuple)
        assert len(product_groups) >=1
        for product_group in product_groups:
            assert isinstance(product_group, ProductGroup)

    def test_quantity_unit_conversions_valid(self):
        quantity_unit_conversions = self.gdm.quantity_unit_conversions().list
        assert isinstance(quantity_unit_conversions, tuple)
        assert len(quantity_unit_conversions) >=1
        for quantity_unit_conversion in quantity_unit_conversions:
            assert isinstance(quantity_unit_conversion, QuantityUnitConversion)

    def test_equipment_valid(self):
        equipments = self.gdm.equipment().list
        assert isinstance(equipments, tuple)
        assert len(equipments) >=1
        for equipment in equipments:
            assert isinstance(equipment, Equipment)

    def test_userfields_valid(self):
        userfields = self.gdm.userfields().list
        assert isinstance(userfields, tuple)
        assert len(userfields) >=1
        for userfield in userfields:
            assert isinstance(userfield, Userfield)

    def test_userentities_valid(self):
        userentities = self.gdm.userentities().list
        assert isinstance(userentities, tuple)
        assert len(userentities) >=1
        for userentity in userentities:
            assert isinstance(userentity, UserEntity)

    def test_userobjects_valid(self):
        userobjects = self.gdm.userobjects().list
        assert isinstance(userobjects, tuple)
        assert len(userobjects) >=1
        for userobject in userobjects:
            assert isinstance(userobject, UserObject)



from .grocy_api_client import GrocyApiClient, GrocyEntity
from .utils import parse_bool

LOCATION_ENDPOINT = 'objects/locations'


class Location(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__name = parsed_json.get('name')
        self.__description = parsed_json.get('description', None)
        self.__is_freezer = parse_bool(parsed_json.get('is_freezer'), False)
        super().__init__(api, endpoint, parsed_json)

    @property
    def name(self) -> str:
        return self.__name

    @property
    def description(self) -> str:
        return self.__description

    @property
    def is_freezer(self) -> bool:
        return self.__is_freezer



from .grocy_api_client import GrocyApiClient, GrocyEntity
from .utils import parse_float, parse_int

QUANTITY_UNIT_CONVERTIONS_ENDPOINT = 'objects/quantity_unit_conversions'


class QuantityUnitConversion(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__from_qu_id = parse_int(parsed_json.get('from_qu_id'))
        self.__to_qu_id = parse_int(parsed_json.get('to_qu_id'))
        self.__factor = parse_float(parsed_json.get('factor'))
        self.__product_id = parse_int(parsed_json.get('product_id'))
        super().__init__(api, endpoint, parsed_json)

    @property
    def from_qu_id(self) -> int:
        return self.__from_qu_id

    @property
    def to_qu_id(self) -> int:
        return self.__to_qu_id

    @property
    def factor(self) -> float:
        return self.__factor

    @property
    def product_id(self) -> int:
        return self.__product_id



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.grocy_api_client import GrocyApiClient
from pygrocydm.product_group import PRODUCT_GROUPS_ENDPOINT, ProductGroup


class TestProductGroup(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = PRODUCT_GROUPS_ENDPOINT + '/1'

    def test_product_group_data_diff_valid(self):
        product_group = self.api.get_request(self.endpoint)
        product_group_keys = product_group.keys()
        moked_product_group_json = """{
            "id": "1",
            "name": "01 Sweets",
            "description": null,
            "row_created_timestamp": "2020-03-05 00:50:10"
        }"""
        moked_keys = json.loads(moked_product_group_json).keys()
        self.assertCountEqual(list(product_group_keys), list(moked_keys))

    def test_parse_json(self):
        product_group = ProductGroup(self.api, PRODUCT_GROUPS_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(product_group.id, int)
        assert isinstance(product_group.description, str) or product_group.description is None
        assert isinstance(product_group.name, str)
        assert isinstance(product_group.row_created_timestamp, datetime)



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.userobject import USEROBJECTS_ENDPOINT, UserObject
from pygrocydm.grocy_api_client import GrocyApiClient


class TestUserEntity(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = USEROBJECTS_ENDPOINT + '/1'

    def test_userobject_data_diff_valid(self):
        userobject = self.api.get_request(self.endpoint)
        userobject_keys = userobject.keys()
        moked_userobject_json = """{
            "id": "1",
            "userentity_id": "1",
            "row_created_timestamp": "2020-03-06 00:50:10"
        }"""
        moked_keys = json.loads(moked_userobject_json).keys()
        self.assertCountEqual(list(userobject_keys), list(moked_keys))

    def test_parse_json(self):
        userobject = UserObject(self.api, USEROBJECTS_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(userobject.id, int)
        assert isinstance(userobject.userentity_id, int)
        assert isinstance(userobject.row_created_timestamp, datetime)



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.grocy_api_client import GrocyApiClient
from pygrocydm.task_category import TASK_CATEGORIES_ENDPOINT, TaskCategory


class TestTaskCategory(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = TASK_CATEGORIES_ENDPOINT + '/1'

    def test_task_category_data_diff_valid(self):
        task_category = self.api.get_request(self.endpoint)
        task_category_keys = task_category.keys()
        moked_task_category_json = """{
            "id": "1",
            "name": "Home",
            "description": null,
            "row_created_timestamp": "2020-03-05 00:50:10"
        }"""
        moked_keys = json.loads(moked_task_category_json).keys()
        self.assertCountEqual(list(task_category_keys), list(moked_keys))

    def test_parse_json(self):
        task_category = TaskCategory(self.api, TASK_CATEGORIES_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(task_category.id, int)
        assert isinstance(task_category.description, str) or task_category.description is None
        assert isinstance(task_category.name, str)
        assert isinstance(task_category.row_created_timestamp, datetime)



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.grocy_api_client import GrocyApiClient
from pygrocydm.quantity_unit_conversion import QUANTITY_UNIT_CONVERTIONS_ENDPOINT, QuantityUnitConversion


class TestQuantityUnitConversion(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = f"{QUANTITY_UNIT_CONVERTIONS_ENDPOINT }/1"

    def test_quantity_unit_conversion_data_diff_valid(self):
        quantity_unit_conversion = self.api.get_request(self.endpoint)
        quantity_unit_conversion_keys = quantity_unit_conversion.keys()
        moked_quantity_unit_conversion_json = """{
            "id": "1",
            "from_qu_id": "3",
            "to_qu_id": "12",
            "factor": "10.0",
            "product_id": "10",
            "row_created_timestamp": "2020-03-05 00:50:10"
        }"""
        moked_keys = json.loads(moked_quantity_unit_conversion_json).keys()
        self.assertCountEqual(list(quantity_unit_conversion_keys), list(moked_keys))

    def test_parse_json(self):
        quantity_unit_conversion = QuantityUnitConversion(self.api, QUANTITY_UNIT_CONVERTIONS_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(quantity_unit_conversion.id, int)
        assert isinstance(quantity_unit_conversion.from_qu_id, int)
        assert isinstance(quantity_unit_conversion.to_qu_id, int)
        assert isinstance(quantity_unit_conversion.id, int)
        assert isinstance(quantity_unit_conversion.factor, float)
        assert isinstance(quantity_unit_conversion.product_id, int)
        assert isinstance(quantity_unit_conversion.row_created_timestamp, datetime)



from .grocy_api_client import GrocyApiClient, GrocyEntity
from .utils import parse_int

USEROBJECTS_ENDPOINT = 'objects/userobjects'


class UserObject(GrocyEntity):
    def __init__(self, api: GrocyApiClient, endpoint: str, parsed_json):
        self.__userentity_id = parse_int(parsed_json.get('userentity_id'))
        super().__init__(api, endpoint, parsed_json)

    @property
    def userentity_id(self) -> int:
        return self.__userentity_id



import json
from datetime import datetime
from test.test_const import CONST_BASE_URL, CONST_PORT, CONST_SSL
from unittest import TestCase

from pygrocydm.userfield import USERFIELDS_ENDPOINT, Userfield, UserfieldType
from pygrocydm.grocy_api_client import GrocyApiClient


class TestUserfield(TestCase):

    def setUp(self):
        self.api = GrocyApiClient(CONST_BASE_URL, "demo_mode",  verify_ssl=CONST_SSL, port=CONST_PORT)
        self.endpoint = USERFIELDS_ENDPOINT + '/1'

    def test_userfield_data_diff_valid(self):
        userfield = self.api.get_request(self.endpoint)
        userfield_keys = userfield.keys()
        moked_userfield_json = """{
            "id": "1",
            "entity": "userentity-exampleuserentity",
            "name": "customfield1",
            "caption": "Custom field 1",
            "type": "text-single-line",
            "show_as_column_in_tables": "1",
            "row_created_timestamp": "2020-03-06 00:50:10",
            "config": null
        }"""
        moked_keys = json.loads(moked_userfield_json).keys()
        self.assertCountEqual(list(userfield_keys), list(moked_keys))

    def test_parse_json(self):
        uf_types = { item.value for item in UserfieldType }
        userfield = Userfield(self.api, USERFIELDS_ENDPOINT, self.api.get_request(self.endpoint))
        assert isinstance(userfield.id, int)
        assert isinstance(userfield.entity, str)
        assert isinstance(userfield.name, str)
        assert isinstance(userfield.caption, str)
        assert isinstance(userfield.type, str) and userfield.type in uf_types
        assert isinstance(userfield.show_as_column_in_tables, bool)
        assert isinstance(userfield.config, str) or userfield.config is None
        assert isinstance(userfield.row_created_timestamp, datetime)
